Struct Spec

pub struct Spec {
    pub description: String,
    pub repository_url: String,
    pub git_ref: String,
    pub command: String,
}
A project specification.

Fields

description: String

The project description.

This gets put on the HTML report front page.

repository_url: String

The project git repository URL.

This is where the project source is cloned from.

git_ref: String

The git ref to use.

This can be anything git checkout can check out. Usually it is a branch name. If it’s a tag or commit id or something else that doesn’t ever change, the wumpus hunter doesn’t get changes to the repository and always runs tests for the same commit.

command: String

The shell command to run to run the test suite.

This will be passed onto the bash shell.

Implementations

Source

impl Spec

pub fn from_file(filename: &Path) -> Result<Self>

Load a Spec from a file.

pub fn versions(&self, run_log: &mut RunLog) -> Result<()>

Query versions of important tools.

pub fn git_clone(&self, working_dir: &Path, run_log: &mut RunLog) -> Result<()>

Clone the specified repository to the desired directory.

pub fn git_remote_update( &self, working_dir: &Path, run_log: &mut RunLog, ) -> Result<()>

Update the information about git remotes checked out repository.

pub fn git_checkout( &self, working_dir: &Path, committish: &str, run_log: &mut RunLog, ) -> Result<()>

Check out the desired ref.

pub fn git_head( &self, working_dir: &Path, run_log: &mut RunLog, ) -> Result<String>

Return the commit id currently checked out.

pub fn git_commit_date( &self, working_dir: &Path, commit: &str, run_log: &mut RunLog, ) -> String

Return the date for a specified commit.

pub fn run_test_suite( &self, working_dir: &Path, timeout: usize, tmpdir: &Path, run_log: &mut RunLog, ) -> Result<(String, bool)>

Run the test suite once.