pub struct Spec {
pub description: String,
pub repository_url: String,
pub git_ref: String,
pub command: String,
}Expand description
A project specification.
Fields
description: StringThe project description.
This gets put on the HTML report front page.
repository_url: StringThe project git repository URL.
This is where the project source is cloned from.
git_ref: StringThe git ref to use.
This can be anything git checkout can check out. Usually it
is a branch name. If it’s a tag or commit id or something else
that doesn’t ever change, the wumpus hunter doesn’t get
changes to the repository and always runs tests for the same
commit.
command: StringThe shell command to run to run the test suite.
This will be passed onto the bash shell.
Implementations
Sourceimpl Spec
impl Spec
Sourcepub fn git_clone(&self, working_dir: &Path, run_log: &mut RunLog) -> Result<()>
pub fn git_clone(&self, working_dir: &Path, run_log: &mut RunLog) -> Result<()>
Clone the specified repository to the desired directory.
Sourcepub fn git_remote_update(
&self,
working_dir: &Path,
run_log: &mut RunLog,
) -> Result<()>
pub fn git_remote_update( &self, working_dir: &Path, run_log: &mut RunLog, ) -> Result<()>
Update the information about git remotes checked out repository.
Sourcepub fn git_checkout(
&self,
working_dir: &Path,
committish: &str,
run_log: &mut RunLog,
) -> Result<()>
pub fn git_checkout( &self, working_dir: &Path, committish: &str, run_log: &mut RunLog, ) -> Result<()>
Check out the desired ref.
Sourcepub fn git_head(
&self,
working_dir: &Path,
run_log: &mut RunLog,
) -> Result<String>
pub fn git_head( &self, working_dir: &Path, run_log: &mut RunLog, ) -> Result<String>
Return the commit id currently checked out.
Sourcepub fn git_commit_date(
&self,
working_dir: &Path,
commit: &str,
run_log: &mut RunLog,
) -> String
pub fn git_commit_date( &self, working_dir: &Path, commit: &str, run_log: &mut RunLog, ) -> String
Return the date for a specified commit.